﻿# 基础配置
<!-- TOC -->

- [基础配置](#基础配置)
    - [设置语言环境](#设置语言环境)
        - [显示当前语言环境状态](#显示当前语言环境状态)
        - [列出可用的语言环境](#列出可用的语言环境)
        - [设置语言环境](#设置语言环境-1)
    - [设置键盘](#设置键盘)
        - [显示当前设置](#显示当前设置)
        - [列出可用的键盘布局](#列出可用的键盘布局)
        - [设置键盘布局](#设置键盘布局)
    - [设置日期和时间](#设置日期和时间)
        - [使用timedatectl命令设置](#使用timedatectl命令设置)
        - [使用date命令设置](#使用date命令设置)
        - [使用hwclock命令设置](#使用hwclock命令设置)
    - [设置kdump](#设置kdump)
        - [设置kdump预留内存](#设置kdump预留内存)
        - [预留内存推荐值](#预留内存推荐值)
        - [禁用网络相关驱动](#禁用网络相关驱动)

<!-- /TOC -->


## 设置语言环境

您可以通过localectl修改系统的语言环境，对应的参数设置保存在/etc/locale.conf文件中。这些参数会在系统启动过程中被systemd的守护进程读取。

### 显示当前语言环境状态

显示当前语言环境，命令如下：

```
$ localectl status
```

例如显示系统当前的设置，命令和输出如下：

```
$ localectl status
   System Locale: LANG=zh_CN.UTF-8
       VC Keymap: cn
      X11 Layout: cn
```

### 列出可用的语言环境

显示当前可用的语言环境，命令如下：

```
$ localectl list-locales
```

例如显示当前系统中所有可用的中文环境，命令和输出如下：

```
$ localectl list-locales | grep zh
zh_CN.UTF-8
```

### 设置语言环境

要设置语言环境，在root权限下执行如下命令，其中  _locale_  是您要设置的语言类型，取值范围可通过**localectl list-locales**获取，请根据实际情况修改。

```
# localectl set-locale LANG=locale
```

例如设置为简体中文语言环境，在root权限下执行如下命令：

```
# localectl set-locale LANG=zh_CN.UTF-8
```

>![](public_sys-resources/icon-note.gif) **说明：**   
>修改后需要重新登录或者在root权限下执行`source /etc/locale.conf`命令刷新配置文件，使修改生效。  


## 设置键盘

您可以通过localectl修改系统的键盘设置，对应的参数设置保存在/etc/locale.conf文件中。这些参数，会在系统启动的早期被systemd的守护进程读取。

### 显示当前设置

显示当前键盘设置，命令如下：

```
$ localectl status
```

例如显示系统当前的设置，命令和输出如下：

```
$ localectl status
   System Locale: LANG=zh_CN.UTF-8
       VC Keymap: cn
      X11 Layout: cn
```

### 列出可用的键盘布局

显示当前可用的键盘布局，命令如下：

```
$ localectl list-keymaps
```

例如显示系统当前的中文键盘布局，命令和输出如下：

```
$ localectl list-keymaps | grep cn
cn
```

### 设置键盘布局

设置键盘布局，在root权限下执行如下命令，其中  _map_  是您想要设置的键盘类型，取值范围可通过**localectl list-keymaps**获取，请根据实际情况修改：

```
# localectl set-keymap map
```

此时设置的键盘布局同样也会应用到图形界面中。

设置完成后，查看当前状态：

```
$ localectl status
   System Locale: LANG=zh_CN.UTF-8
       VC Keymap: cn
      X11 Layout: us
```

## 设置日期和时间

本节介绍如何通过timedatectl、date、hwclock命令来设置系统的日期、时间和时区等。



### 使用timedatectl命令设置

#### 显示日期和时间

显示当前的日期和时间，命令如下：

```
$ timedatectl
```

例如显示系统当前的日期和时间，命令和输出如下：

```
$ timedatectl
               Local time: Mon 2019-09-30 04:05:00 EDT
           Universal time: Mon 2019-09-30 08:05:00 UTC
                 RTC time: Mon 2019-09-30 08:05:00
                Time zone: America/New_York (EDT, -0400)
System clock synchronized: no
              NTP service: inactive
          RTC in local TZ: no
```

#### 通过远程服务器进行时间同步

您可以启用NTP远程服务器进行系统时钟的自动同步。是否启用NTP，可在root权限下执行如下命令进行设置。其中  _boolean_  可取值yes和no，分别表示启用和不启用NTP进行系统时钟自动同步，请根据实际情况修改。

>![](public_sys-resources/icon-note.gif) **说明：**   
>若启用了NTP远程服务器进行系统时钟自动同步，则不能手动修改日期和时间。若需要手动修改日期或时间，则需确保已经关闭NTP系统时钟自动同步。可执行**timedatectl set-ntp**  no命令进行关闭。  

```
# timedatectl set-ntp boolean
```

例如开启自动远程时间同步，命令如下：

```
# timedatectl set-ntp yes
```

#### 修改日期

>![](public_sys-resources/icon-note.gif) **说明：**   
>修改日期前，请确保已经关闭NTP系统时钟自动同步。  

修改当前的日期，在root权限下执行如下命令，其中  _YYYY_  代表年份，_MM_  代表月份，_DD_  代表某天，请根据实际情况修改：

```
# timedatectl set-time YYYY-MM-DD
```

例如修改当前的日期为2019年8月14号，命令如下：

```
# timedatectl set-time '2019-08-14'
```

#### 修改时间

>![](public_sys-resources/icon-note.gif) **说明：**   
>修改时间前，请确保已经关闭NTP系统时钟自动同步。  

修改当前的时间，在root权限下执行如下命令，其中  _HH_  代表小时，_MM_  代表分钟，_SS_  代表秒，请根据实际情况修改：

```
# timedatectl set-time HH:MM:SS
```

例如修改当前的时间为15点57分24秒，命令如下：

```
# timedatectl set-time 15:57:24
```

#### 修改时区

显示当前可用时区，命令如下：

```
$ timedatectl list-timezones
```

要修改当前的时区，在root权限下执行如下命令，其中  _time\_zone_  是您想要设置的时区，请根据实际情况修改：

```
# timedatectl set-timezone time_zone
```

例如修改当前的时区，首先查询所在地域的可用时区，此处以Asia为例：

```
# timedatectl list-timezones | grep Asia
Asia/Aden
Asia/Almaty
Asia/Amman
Asia/Anadyr
Asia/Aqtau
Asia/Aqtobe
Asia/Ashgabat
Asia/Baghdad
Asia/Bahrain
……

Asia/Seoul
Asia/Shanghai
Asia/Singapore
Asia/Srednekolymsk
Asia/Taipei
Asia/Tashkent
Asia/Tbilisi
Asia/Tehran
Asia/Thimphu
Asia/Tokyo
```

然后修改当前的时区为“Asia/Shanghai”，命令如下：

```
# timedatectl set-timezone Asia/Shanghai
```

### 使用date命令设置

#### 显示当前的日期和时间

显示当前的日期和时间，命令如下：

```
$ date
```

默认情况下，date命令显示本地时间。要显示UTC时间，添加\-\-utc或-u参数：

```
$ date --utc
```

要自定义对应的输出信息格式，添加 +"format" 参数：

```
$ date +"format"
```

**表 1**  参数说明

<a name="zh-cn_topic_0151920961_t5113feb6bf86416883c941865a536aae"></a>
<table><thead align="left"><tr id="zh-cn_topic_0151920961_r2ad2cb74e72f4a52ab523486d1fb5e23"><th class="cellrowborder" valign="top" width="18.23%" id="mcps1.2.3.1.1"><p id="zh-cn_topic_0151920961_a995c5cbca5ec49f48097e94e0692222e"><a name="zh-cn_topic_0151920961_a995c5cbca5ec49f48097e94e0692222e"></a><a name="zh-cn_topic_0151920961_a995c5cbca5ec49f48097e94e0692222e"></a>格式参数</p>
</th>
<th class="cellrowborder" valign="top" width="81.77%" id="mcps1.2.3.1.2"><p id="zh-cn_topic_0151920961_a2c082d7678c14c54acae9c32cb46efa9"><a name="zh-cn_topic_0151920961_a2c082d7678c14c54acae9c32cb46efa9"></a><a name="zh-cn_topic_0151920961_a2c082d7678c14c54acae9c32cb46efa9"></a>说明</p>
</th>
</tr>
</thead>
<tbody><tr id="zh-cn_topic_0151920961_r4bf64ec46df3458db0b40dd2597b96a4"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_a7c84b16430784236af6f428bb03354e6"><a name="zh-cn_topic_0151920961_a7c84b16430784236af6f428bb03354e6"></a><a name="zh-cn_topic_0151920961_a7c84b16430784236af6f428bb03354e6"></a>%H</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_af1ad9a0cf0f74e28905916c24e9a624c"><a name="zh-cn_topic_0151920961_af1ad9a0cf0f74e28905916c24e9a624c"></a><a name="zh-cn_topic_0151920961_af1ad9a0cf0f74e28905916c24e9a624c"></a>小时以HH格式（例如 17）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r81bd46c86c484a2d8127ac25f8cd3f84"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_ac75c896629a94f5a948ecf00d9ae846c"><a name="zh-cn_topic_0151920961_ac75c896629a94f5a948ecf00d9ae846c"></a><a name="zh-cn_topic_0151920961_ac75c896629a94f5a948ecf00d9ae846c"></a>%M</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a713b23439f944c7e89dad6ad8fd3a00b"><a name="zh-cn_topic_0151920961_a713b23439f944c7e89dad6ad8fd3a00b"></a><a name="zh-cn_topic_0151920961_a713b23439f944c7e89dad6ad8fd3a00b"></a>分钟以MM格式（例如 37）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r01f5733f51244eb08597f035a86f62d3"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_a83cbeee8d15d4ab19166f8859aca3c94"><a name="zh-cn_topic_0151920961_a83cbeee8d15d4ab19166f8859aca3c94"></a><a name="zh-cn_topic_0151920961_a83cbeee8d15d4ab19166f8859aca3c94"></a>%S</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a198c8d8580fa4d00b3a701f522cf2eb3"><a name="zh-cn_topic_0151920961_a198c8d8580fa4d00b3a701f522cf2eb3"></a><a name="zh-cn_topic_0151920961_a198c8d8580fa4d00b3a701f522cf2eb3"></a>秒以SS格式（例如 25）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r8bdf9b4c58f24f6982fc6b6b3def6ec3"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_a52b3ddb644664af794aed0ceef431eae"><a name="zh-cn_topic_0151920961_a52b3ddb644664af794aed0ceef431eae"></a><a name="zh-cn_topic_0151920961_a52b3ddb644664af794aed0ceef431eae"></a>%d</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a0d60b507d1064efdb930ff4800d11205"><a name="zh-cn_topic_0151920961_a0d60b507d1064efdb930ff4800d11205"></a><a name="zh-cn_topic_0151920961_a0d60b507d1064efdb930ff4800d11205"></a>日期以DD格式（例如 15）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r6156a88a26d14f2f89e6540944718f47"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_a312fb7c0a5ad48dfb2e9b7d17e99c1d9"><a name="zh-cn_topic_0151920961_a312fb7c0a5ad48dfb2e9b7d17e99c1d9"></a><a name="zh-cn_topic_0151920961_a312fb7c0a5ad48dfb2e9b7d17e99c1d9"></a>%m</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a893723adba374d028ebb80fed09bf3e6"><a name="zh-cn_topic_0151920961_a893723adba374d028ebb80fed09bf3e6"></a><a name="zh-cn_topic_0151920961_a893723adba374d028ebb80fed09bf3e6"></a>月份以MM格式（例如 07）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r34b505f1fd7741cfb1780a831fbf72d2"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_ac01465841ba64c03ae64788361a25a4e"><a name="zh-cn_topic_0151920961_ac01465841ba64c03ae64788361a25a4e"></a><a name="zh-cn_topic_0151920961_ac01465841ba64c03ae64788361a25a4e"></a>%Y</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a6419efda4cdc4072914756ebb31ec1fa"><a name="zh-cn_topic_0151920961_a6419efda4cdc4072914756ebb31ec1fa"></a><a name="zh-cn_topic_0151920961_a6419efda4cdc4072914756ebb31ec1fa"></a>年份以YYYY格式（例如 2019）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r2a7d4de380fe4194ab6d757429583f60"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_ada7b17d82b7b45668fef67f483b31b33"><a name="zh-cn_topic_0151920961_ada7b17d82b7b45668fef67f483b31b33"></a><a name="zh-cn_topic_0151920961_ada7b17d82b7b45668fef67f483b31b33"></a>%Z</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_ac10a70e17c7b4dab86f97d3e460849a8"><a name="zh-cn_topic_0151920961_ac10a70e17c7b4dab86f97d3e460849a8"></a><a name="zh-cn_topic_0151920961_ac10a70e17c7b4dab86f97d3e460849a8"></a>时区缩写（例如CEST）。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r65c5b28a951b4f10a0ab67d51ea41c75"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_aaf432a3ed9c548d7bd3b45929723ca72"><a name="zh-cn_topic_0151920961_aaf432a3ed9c548d7bd3b45929723ca72"></a><a name="zh-cn_topic_0151920961_aaf432a3ed9c548d7bd3b45929723ca72"></a>%F</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a7a6917b7cf9a46759467cd140afc17e9"><a name="zh-cn_topic_0151920961_a7a6917b7cf9a46759467cd140afc17e9"></a><a name="zh-cn_topic_0151920961_a7a6917b7cf9a46759467cd140afc17e9"></a>日期整体格式为YYYY-MM-DD（例如 2019-7-15），等同%Y-%m-%d。</p>
</td>
</tr>
<tr id="zh-cn_topic_0151920961_r722205ab957549d187a171eb72cb040b"><td class="cellrowborder" valign="top" width="18.23%" headers="mcps1.2.3.1.1 "><p id="zh-cn_topic_0151920961_a2e925e19328a49b082150aadec3869a2"><a name="zh-cn_topic_0151920961_a2e925e19328a49b082150aadec3869a2"></a><a name="zh-cn_topic_0151920961_a2e925e19328a49b082150aadec3869a2"></a>%T</p>
</td>
<td class="cellrowborder" valign="top" width="81.77%" headers="mcps1.2.3.1.2 "><p id="zh-cn_topic_0151920961_a7dafd8b31b2e47da84f62588b5290fe6"><a name="zh-cn_topic_0151920961_a7dafd8b31b2e47da84f62588b5290fe6"></a><a name="zh-cn_topic_0151920961_a7dafd8b31b2e47da84f62588b5290fe6"></a>时间整体格式为HH:MM:SS（例如 18:30:25），等同%H:%M:%S。</p>
</td>
</tr>
</tbody>
</table>

实际使用示例如下：

-   显示当前的日期和本地时间。

    ```
    $ date 
    2019年 08月 17日 星期六 17:26:34 CST
    ```

-   显示当前的日期和UTC时间。

    ```
    $ date --utc
    2019年 08月 17日 星期六 09:26:18 UTC
    ```

-   自定义date命令的输出。

    ```
    $ date +"%Y-%m-%d %H:%M"
    2019-08-17 17:24
    ```


#### 修改时间

要修改当前的时间，添加\-\-set或者-s参数。在root权限下执行如下命令，其中  _HH_  代表小时，_MM_  代表分钟，_SS_  代表秒，请根据实际情况修改：

```
# date --set HH:MM:SS
```

默认情况下， date命令设置本地时间。要设置UTC时间，添加\-\-utc或-u参数：

```
# date --set HH:MM:SS --utc
```

例如修改当前的时间为23点26分00秒，在root权限下执行如下命令：

```
# date --set 23:26:00
```

#### 修改日期

修改当前的日期，添加\-\-set或者-s参数。在root权限下执行如下命令，其中  _YYYY_  代表年份，_MM_  代表月份，_DD_  代表某天，请根据实际情况修改：

```
# date --set YYYY-MM-DD
```

例如修改当前的日期为2019年11月2日，命令如下：

```
# date --set 2019-11-02
```

### 使用hwclock命令设置

可以使用 hwclock 命令设置硬件时钟RTC \(Real Time Clock\) 。

#### 硬件时钟和系统时钟

Linux 将时钟分为：

-   系统时钟 \(System Clock\) ：当前Linux Kernel中的时钟。
-   硬件时钟 RTC：主板上由电池供电的主板硬件时钟，该时钟可以在BIOS的 "Standard BIOS Feature" 项中进行设置。

当Linux启动时，会读取硬件时钟，并根据硬件时间来设置系统时间。

#### 显示日期和时间

显示当前硬件的日期和时间，在root权限下执行如下命令：

```
# hwclock
```

例如显示当前硬件的日期和时间，命令和输出如下：

```
# hwclock
2019-08-26 10:18:42.528948+08:00
```

#### 设置日期和时间

修改当前硬件的日期和时间，在root权限下执行如下命令，其中  _dd_  表示日，_mm_  表示月份，_yyyy_  表示年份，_HH_  表示小时，_MM_  表示分钟，请根据实际情况修改：

```
# hwclock --set --date "dd mm yyyy HH:MM"
```

例如修改当前的时间为2019年10月21日21点17分，命令如下：

```
# hwclock --set --date "21 Oct 2019 21:17" --utc
```

## 设置kdump
本节介绍如何设置kdump预留内存及kdump配置文件参数修改。



### 设置kdump预留内存
#### 预留内存参数格式

kdump预留内存参数必须添加到内核启动参数中，配置文件为/boot/efi/EFI/openEuler/grub.cfg，openEuler发布版本中默认已经添加，可以根据实际使用情况调整。添加和修改启动参数后，重启系统生效。kdump预留内存参数格式如下：

| 内核启动参数             | 描述                                        | 默认值           | 备注                                                         |
|--------------------|-------------------------------------------|---------------|------------------------------------------------------------|
| crashkernel=x      | 在4G以下的物理内存预留x大小的内存给kdump使用。               | x86版本默认配置512M | 该配置方法只在4G以下内存预留，必须保证4G以下连续可用内存足够预留。                        |
| crashkernel=x@y    | 在y起始地址预留x大小的内存给kdump使用。                   | 未使用           | 需要确保y起始地址的x大小的内存未被其他模块预留。                                  |
| crashkernel=x,high | 在4G以下的物理内存中预留256M内存，在4G以上预留x大小内存给kdump使用。 | arm64版本默认配置1024M,high           | 需要确保4G以下有256M连续可用的物理内存，4G以上有连续的x大小的连续物理内存。实际预留内存大小为256M+x。 |
| crashkernel=x,low crashkernel=y,high | 在4G以下的物理内存中预留x大小，在4G以上预留y大小内存给kdump使用。                                          | 未使用              | 需要确保4G以下有连续的x大小物理内存，4G以上有连续的y大小物理内存。                                                           |


### 预留内存推荐值
| 推荐方案 | 预留参数                   | 参数说明                                         |
|------|------------------------|----------------------------------------------|
| 通用方案 | crashkernel=2048M,high | 4G以下预留256M，4G以上预留2048M内存给kdump使用。共256+2048M。 |
| 经济方案 | crashkernel=1024M,high | 4G以下预留256M，4G以上预留1024M内存给kdump使用。共256+1024M。 推荐系统512G内存以内的场景，并不使用网络转储kdump文件。对于虚拟机场景，可以适当减少内存预留值，推荐虚拟机设置为crashkernel=512M或者crashkernel=256M,high |
>![](public_sys-resources/icon-note.gif) **说明：**   
>不通过网络转储kdump文件时，需要设置kdump文件系统不打包网络相关驱动。网络驱动加载需要申请较大内存，可能导致预留内存不足，kdump失败。因此建议禁用网络相关驱动。


### 禁用网络相关驱动
kdump配置文件（/etc/kdump.conf）中，dracut参数可以设置裁剪的驱动模块，可以将网络驱动配置到裁剪驱动列表中，让kdump文件系统中不加载该驱动，修改配置文件后，重启kdump服务生效。dracut参数配置如下所示：

`dracut_args --omit-drivers "mdio-gpi usb_8dev et1011c rt2x00usb bcm-phy-lib mac80211_hwsim rtl8723be rndis_host hns3_cae amd vrf rtl8192cu mt76x02-lib int51x1 ppp_deflate team_mode_loadbalance smsc911x aweth bonding mwifiex_usb hnae dnet rt2x00pci vaser_pci hdlc_ppp marvell rtl8xxxu mlxsw_i2c ath9k_htc rtl8150 smc91x cortina at803x rockchip cxgb4 spi_ks8995 mt76x2u smsc9420 mdio-cavium bnxt_en ch9200 dummy macsec ice mt7601u rtl8188ee ixgbevf net1080 liquidio_vf be2net mlxsw_switchx2 gl620a xilinx_gmii2rgmii ppp_generic rtl8192de sja1000_platform ath10k_core cc770_platform realte igb c_can_platform c_can ethoc dm9601 smsc95xx lg-vl600 ifb enic ath9 mdio-octeon ppp_mppe ath10k_pci cc770 team_mode_activebackup marvell10g hinic rt2x00lib mlx4_en iavf broadcom igc c_can_pci alx rtl8192se rtl8723ae microchip lan78xx atl1c rtl8192c-common almia ax88179_178a qed netxen_nic brcmsmac rt2800usb e1000 qla3xxx mdio-bitbang qsemi mdio-mscc-miim plx_pci ipvlan r8152 cx82310_eth slhc mt76x02-usb ems_pci xen-netfront usbnet pppoe mlxsw_minimal mlxsw_spectrum cdc_ncm rt2800lib rtl_usb hnae3 ath9k_common ath9k_hw catc mt76 hns_enet_drv ppp_async huawei_cdc_ncm i40e rtl8192ce dl2 qmi_wwan mii peak_usb plusb can-dev slcan amd-xgbe team_mode_roundrobin ste10Xp thunder_xcv pptp thunder_bgx ixgbe davicom icplus tap tun smsc75xx smsc dlci hns_dsaf mlxsw_core rt2800mmi softing uPD60620 vaser_usb dp83867 brcmfmac mwifiex_pcie mlx4_core micrel team macvlan bnx2 virtio_net rtl_pci zaurus hns_mdi libcxgb hv_netvsc nicvf mt76x0u teranetics mlxfw cdc_eem qcom-emac pppox mt76-usb sierra_net i40evf bcm87xx mwifiex pegasus rt2x00mmi sja1000 ena hclgevf cnic cxgb4vf ppp_synctty iwlmvm team_mode_broadcast vxlan vsockmon hdlc_cisc rtl8723-common bsd_comp fakelb dp83822 dp83tc811 cicada fm10 8139t sfc hs geneve hclge xgene-enet-v2 cdc_mbim hdlc asix netdevsim rt2800pci team_mode_random lxt ems_usb mlxsw_pci sr9700 mdio-thunder mlxsw_switchib macvtap atlantic cdc_ether mcs7830 nicpf mdi peak_pci atl1e cdc_subset ipvtap btcoexist mt76x0-common veth slip iwldvm bcm7xxx vitesse netconsole epic100 myri10ge r8169 qede microchip_t1 liquidi bnx2x brcmutil mwifiex_sdi mlx5_core rtlwifi vmxnet3 nlmon hns3 hdlc_raw esd_usb2 atl2 mt76x2-common iwlwifi mdio-bcm-unimac national ath rtwpci rtw88 nfp rtl8821ae fjes thunderbolt-net 8139cp atl1 mscc vcan dp83848 dp83640 hdlc_fr e1000e ipheth net_failover aquantia rtl8192ee igbvf rocker intel-xway tg3" --omit "ramdisk network ifcfg qemu-net" --install "chmod" --nofscks`
